@@ -10,13 +10,12 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from cinderclient.client import Client as cinder_client
+from cinderclient.client import Client
 
 
 class CinderHealth(object):
-
     def __init__(self, creds):
-        self.cinderclient = cinder_client(2, **creds)
+        self.cinderclient = Client(**creds)
 
     def cinder_list(self):
         try:
